Instream v0.16.0 Instream.Data.Write View Source

Database write query helper.

Link to this section Summary

Functions

Determines the proper database to write points to

Creates a writing query object from a single or a list of points

Link to this section Functions

Link to this function determine_database(arg1, opts) View Source
determine_database(map | [map], Keyword.t) :: String.t | nil

Determines the proper database to write points to.

Later usage depends on the writer.

Link to this function query(payload, opts) View Source
query(map | [map], Keyword.t) :: Instream.Query.t

Creates a writing query object from a single or a list of points.